@@ -9,7 +9,7 @@ use uv_distribution_filename::DistExtension;
 use uv_distribution_types::{
     Index, IndexLocations, IndexMetadata, IndexName, Origin, Requirement, RequirementSource,
 };
-use uv_git_types::{GitReference, GitUrl, GitUrlParseError};
+use uv_git_types::{GitLfs, GitReference, GitUrl, GitUrlParseError};
 use uv_normalize::{ExtraName, GroupName, PackageName};
 use uv_pep440::VersionSpecifiers;
 use uv_pep508::{MarkerTree, VerbatimUrl, VersionOrUrl, looks_like_git_repository};
@@ -166,6 +166,7 @@ impl LoweredRequirement {
                             rev,
                             tag,
                             branch,
+                            lfs,
                             marker,
                             ..
                         } => {
@@ -175,6 +176,7 @@ impl LoweredRequirement {
                                 rev,
                                 tag,
                                 branch,
+                                lfs,
                             )?;
                             (source, marker)
                         }
@@ -407,6 +409,7 @@ impl LoweredRequirement {
                             rev,
                             tag,
                             branch,
+                            lfs,
                             marker,
                             ..
                         } => {
@@ -416,6 +419,7 @@ impl LoweredRequirement {
                                 rev,
                                 tag,
                                 branch,
+                                lfs,
                             )?;
                             (source, marker)
                         }
@@ -580,6 +584,7 @@ fn git_source(
     rev: Option<String>,
     tag: Option<String>,
     branch: Option<String>,
+    lfs: Option<bool>,
 ) -> Result<RequirementSource, LoweringError> {
     let reference = match (rev, tag, branch) {
         (None, None, None) => GitReference::DefaultBranch,
@@ -595,19 +600,32 @@ fn git_source(
         let path = format!("{}@{}", url.path(), rev);
         url.set_path(&path);
     }
+    let mut frags: Vec<String> = Vec::new();
     if let Some(subdirectory) = subdirectory.as_ref() {
         let subdirectory = subdirectory
             .to_str()
             .ok_or_else(|| LoweringError::NonUtf8Path(subdirectory.to_path_buf()))?;
-        url.set_fragment(Some(&format!("subdirectory={subdirectory}")));
+        frags.push(format!("subdirectory={subdirectory}"));
     }
+    // Loads Git LFS Enablement according to priority.
+    // First: lfs = true, lfs = false from pyproject.toml
+    // Second: UV_GIT_LFS from environment
+    let lfs = GitLfs::from(lfs);
+    // Preserve that we're using Git LFS in the Verbatim Url representations
+    if lfs.enabled() {
+        frags.push("lfs=true".to_string());
+    }
+    if !frags.is_empty() {
+        url.set_fragment(Some(&frags.join("&")));
+    }
+
     let url = VerbatimUrl::from_url(url);
 
     let repository = git.clone();
 
     Ok(RequirementSource::Git {
         url,
-        git: GitUrl::from_reference(repository, reference)?,
+        git: GitUrl::from_fields(repository, reference, None, lfs)?,
         subdirectory,
     })
 }
