@@ -7,21 +7,19 @@ use anyhow::Result;
 use rustc_hash::FxHashSet;
 
 use uv_cache::Cache;
-use uv_configuration::{
-    BuildKind, BuildOptions, BuildOutput, ConfigSettings, PackageConfigSettings, SourceStrategy,
-};
+use uv_configuration::{BuildKind, BuildOptions, BuildOutput, SourceStrategy};
 use uv_distribution_filename::DistFilename;
 use uv_distribution_types::{
-    CachedDist, DependencyMetadata, DistributionId, ExtraBuildRequires, ExtraBuildVariables,
-    IndexCapabilities, IndexLocations, InstalledDist, IsBuildBackendError, Requirement, Resolution,
-    SourceDist,
+    CachedDist, ConfigSettings, DependencyMetadata, DistributionId, ExtraBuildRequires,
+    ExtraBuildVariables, IndexCapabilities, IndexLocations, InstalledDist, IsBuildBackendError,
+    PackageConfigSettings, Requirement, Resolution, SourceDist,
 };
 use uv_git::GitResolver;
-use uv_pep508::PackageName;
+use uv_normalize::PackageName;
 use uv_python::{Interpreter, PythonEnvironment};
 use uv_workspace::WorkspaceCache;
 
-use crate::BuildArena;
+use crate::{BuildArena, BuildIsolation};
 
 ///  Avoids cyclic crate dependencies between resolver, installer and builder.
 ///
@@ -89,6 +87,9 @@ pub trait BuildContext {
     /// This method exists to avoid fetching source distributions if we know we can't build them.
     fn build_options(&self) -> &BuildOptions;
 
+    /// The isolation mode used for building source distributions.
+    fn build_isolation(&self) -> BuildIsolation<'_>;
+
     /// The [`ConfigSettings`] used to build distributions.
     fn config_settings(&self) -> &ConfigSettings;
 
