@@ -190,20 +190,22 @@ pub(crate) async fn lock(
     let state = UniversalState::default();
 
     // Perform the lock operation.
-    match LockOperation::new(
-        mode,
-        &settings,
-        &client_builder,
-        &state,
-        Box::new(DefaultResolveLogger),
-        concurrency,
-        cache,
-        &workspace_cache,
-        printer,
-        preview,
+    match Box::pin(
+        LockOperation::new(
+            mode,
+            &settings,
+            &client_builder,
+            &state,
+            Box::new(DefaultResolveLogger),
+            concurrency,
+            cache,
+            &workspace_cache,
+            printer,
+            preview,
+        )
+        .with_refresh(&refresh)
+        .execute(target),
     )
-    .with_refresh(&refresh)
-    .execute(target)
     .await
     {
         Ok(lock) => {
@@ -355,7 +357,7 @@ impl<'env> LockOperation<'env> {
                     .ok_or_else(|| ProjectError::MissingLockfile)?;
 
                 // Perform the lock operation, but don't write the lockfile to disk.
-                let result = do_lock(
+                let result = Box::pin(do_lock(
                     target,
                     interpreter,
                     Some(existing),
@@ -370,7 +372,7 @@ impl<'env> LockOperation<'env> {
                     self.workspace_cache,
                     self.printer,
                     self.preview,
-                )
+                ))
                 .await?;
 
                 // If the lockfile changed, return an error.
@@ -399,7 +401,7 @@ impl<'env> LockOperation<'env> {
                 };
 
                 // Perform the lock operation.
-                let result = do_lock(
+                let result = Box::pin(do_lock(
                     target,
                     interpreter,
                     existing,
@@ -414,7 +416,7 @@ impl<'env> LockOperation<'env> {
                     self.workspace_cache,
                     self.printer,
                     self.preview,
-                )
+                ))
                 .await?;
 
                 // If the lockfile changed, write it to disk.
