@@ -5,11 +5,13 @@ use std::str::FromStr;
 use anyhow::{Result, bail};
 use owo_colors::OwoColorize;
 use tracing::debug;
+use uv_python::downloads::ManagedPythonDownloadList;
 
 use uv_cache::Cache;
 use uv_client::BaseClientBuilder;
-use uv_configuration::{DependencyGroupsWithDefaults, PreviewMode};
+use uv_configuration::DependencyGroupsWithDefaults;
 use uv_fs::Simplified;
+use uv_preview::Preview;
 use uv_python::{
     EnvironmentPreference, PYTHON_VERSION_FILENAME, PythonDownloads, PythonInstallation,
     PythonPreference, PythonRequest, PythonVersionFile, VersionFileDiscoveryOptions,
@@ -22,7 +24,6 @@ use crate::commands::{
     ExitStatus, project::find_requires_python, reporters::PythonDownloadReporter,
 };
 use crate::printer::Printer;
-use crate::settings::NetworkSettings;
 
 /// Pin to a specific Python version.
 #[allow(clippy::fn_params_excessive_bools)]
@@ -36,10 +37,10 @@ pub(crate) async fn pin(
     global: bool,
     rm: bool,
     install_mirrors: PythonInstallMirrors,
-    network_settings: NetworkSettings,
+    client_builder: BaseClientBuilder<'_>,
     cache: &Cache,
     printer: Printer,
-    preview: PreviewMode,
+    preview: Preview,
 ) -> Result<ExitStatus> {
     let workspace_cache = WorkspaceCache::default();
     let virtual_project = if no_project {
@@ -96,10 +97,17 @@ pub(crate) async fn pin(
             for pin in file.versions() {
                 writeln!(printer.stdout(), "{}", pin.to_canonical_string())?;
                 if let Some(virtual_project) = &virtual_project {
+                    let client = client_builder.clone().retries(0).build();
+                    let download_list = ManagedPythonDownloadList::new(
+                        &client,
+                        install_mirrors.python_downloads_json_url.as_deref(),
+                    )
+                    .await?;
                     warn_if_existing_pin_incompatible_with_project(
                         pin,
                         virtual_project,
                         python_preference,
+                        &download_list,
                         cache,
                         preview,
                     );
@@ -115,11 +123,6 @@ pub(crate) async fn pin(
         bail!("Requests for arbitrary names (e.g., `{name}`) are not supported in version files");
     }
 
-    let client_builder = BaseClientBuilder::new()
-        .retries_from_env()?
-        .connectivity(network_settings.connectivity)
-        .native_tls(network_settings.native_tls)
-        .allow_insecure_host(network_settings.allow_insecure_host.clone());
     let reporter = PythonDownloadReporter::single(printer);
 
     let python = match PythonInstallation::find_or_download(
@@ -269,8 +272,9 @@ fn warn_if_existing_pin_incompatible_with_project(
     pin: &PythonRequest,
     virtual_project: &VirtualProject,
     python_preference: PythonPreference,
+    downloads_list: &ManagedPythonDownloadList,
     cache: &Cache,
-    preview: PreviewMode,
+    preview: Preview,
 ) {
     // Check if the pinned version is compatible with the project.
     if let Some(pin_version) = pep440_version_from_request(pin) {
@@ -294,6 +298,7 @@ fn warn_if_existing_pin_incompatible_with_project(
         pin,
         EnvironmentPreference::OnlySystem,
         python_preference,
+        downloads_list,
         cache,
         preview,
     ) {
