@@ -78,9 +78,7 @@ fn mixed_credentials() {
         .arg("always")
         .arg("../../scripts/links/ok-1.0.0-py3-none-any.whl")
         // Emulate CI
-        .env(EnvVars::GITHUB_ACTIONS, "true")
-        // Just to make sure
-        .env_remove(EnvVars::ACTIONS_ID_TOKEN_REQUEST_TOKEN), @r###"
+        .env(EnvVars::GITHUB_ACTIONS, "true"), @r###"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -104,9 +102,7 @@ fn missing_trusted_publishing_permission() {
         .arg("always")
         .arg("../../scripts/links/ok-1.0.0-py3-none-any.whl")
         // Emulate CI
-        .env(EnvVars::GITHUB_ACTIONS, "true")
-        // Just to make sure
-        .env_remove(EnvVars::ACTIONS_ID_TOKEN_REQUEST_TOKEN), @r###"
+        .env(EnvVars::GITHUB_ACTIONS, "true"), @r"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -114,8 +110,10 @@ fn missing_trusted_publishing_permission() {
     ----- stderr -----
     Publishing 1 file to https://test.pypi.org/legacy/
     error: Failed to obtain token for trusted publishing
-      Caused by: Environment variable ACTIONS_ID_TOKEN_REQUEST_TOKEN not set, is the `id-token: write` permission missing?
-    "###
+      Caused by: Failed to obtain OIDC token: is the `id-token: write` permission missing?
+      Caused by: GitHub Actions detection error
+      Caused by: insufficient permissions: missing ACTIONS_ID_TOKEN_REQUEST_URL
+    "
     );
 }
 
@@ -130,9 +128,7 @@ fn no_credentials() {
         .arg("https://test.pypi.org/legacy/")
         .arg("../../scripts/links/ok-1.0.0-py3-none-any.whl")
         // Emulate CI
-        .env(EnvVars::GITHUB_ACTIONS, "true")
-        // Just to make sure
-        .env_remove(EnvVars::ACTIONS_ID_TOKEN_REQUEST_TOKEN), @r"
+        .env(EnvVars::GITHUB_ACTIONS, "true"), @r"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -141,7 +137,9 @@ fn no_credentials() {
     Publishing 1 file to https://test.pypi.org/legacy/
     Note: Neither credentials nor keyring are configured, and there was an error fetching the trusted publishing token. If you don't want to use trusted publishing, you can ignore this error, but you need to provide credentials.
     error: Trusted publishing failed
-      Caused by: Environment variable ACTIONS_ID_TOKEN_REQUEST_TOKEN not set, is the `id-token: write` permission missing?
+      Caused by: Failed to obtain OIDC token: is the `id-token: write` permission missing?
+      Caused by: GitHub Actions detection error
+      Caused by: insufficient permissions: missing ACTIONS_ID_TOKEN_REQUEST_URL
     Uploading ok-1.0.0-py3-none-any.whl ([SIZE])
     error: Failed to publish `../../scripts/links/ok-1.0.0-py3-none-any.whl` to https://test.pypi.org/legacy/
       Caused by: Failed to send POST request
@@ -188,7 +186,7 @@ fn dubious_filenames() {
         .arg("dummy")
         .arg("--publish-url")
         .arg("https://test.pypi.org/legacy/")
-        .arg(context.temp_dir.join("*")), @r###"
+        .arg(context.temp_dir.join("*")), @r"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -198,7 +196,7 @@ fn dubious_filenames() {
     warning: Skipping file that looks like a distribution, but is not a valid distribution filename: `[TEMP_DIR]/not-a-wheel.whl`
     warning: Skipping file that looks like a distribution, but is not a valid distribution filename: `[TEMP_DIR]/not-sdist-1-2-3-asdf.zip`
     error: No files found to publish
-    "###
+    "
     );
 }
 
@@ -500,3 +498,111 @@ async fn read_index_credential_env_vars_for_check_url() {
     "
     );
 }
+
+/// Native GitLab CI trusted publishing using `PYPI_ID_TOKEN`
+#[tokio::test]
+async fn gitlab_trusted_publishing_pypi_id_token() {
+    let context = TestContext::new("3.12");
+
+    let server = MockServer::start().await;
+
+    // Audience endpoint (PyPI)
+    Mock::given(method("GET"))
+        .and(path("/_/oidc/audience"))
+        .respond_with(
+            ResponseTemplate::new(200).set_body_raw("{\"audience\":\"pypi\"}", "application/json"),
+        )
+        .mount(&server)
+        .await;
+
+    // Mint token endpoint returns a short-lived API token
+    Mock::given(method("POST"))
+        .and(path("/_/oidc/mint-token"))
+        .respond_with(
+            ResponseTemplate::new(200).set_body_raw("{\"token\":\"apitoken\"}", "application/json"),
+        )
+        .mount(&server)
+        .await;
+
+    // Upload endpoint requires the minted token as Basic auth
+    Mock::given(method("POST"))
+        .and(path("/upload"))
+        .and(basic_auth("__token__", "apitoken"))
+        .respond_with(ResponseTemplate::new(200))
+        .mount(&server)
+        .await;
+
+    uv_snapshot!(context.filters(), context.publish()
+        .arg("--trusted-publishing")
+        .arg("always")
+        .arg("--publish-url")
+        .arg(format!("{}/upload", server.uri()))
+        .arg("../../scripts/links/ok-1.0.0-py3-none-any.whl")
+        .env(EnvVars::GITLAB_CI, "true")
+        .env_remove(EnvVars::GITHUB_ACTIONS)
+        .env("PYPI_ID_TOKEN", "gitlab-oidc-jwt"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Publishing 1 file to http://[LOCALHOST]/upload
+    Uploading ok-1.0.0-py3-none-any.whl ([SIZE])
+    "
+    );
+}
+
+/// Native GitLab CI trusted publishing using `TESTPYPI_ID_TOKEN`
+#[tokio::test]
+async fn gitlab_trusted_publishing_testpypi_id_token() {
+    let context = TestContext::new("3.12");
+
+    let server = MockServer::start().await;
+
+    // Audience endpoint (TestPyPI)
+    Mock::given(method("GET"))
+        .and(path("/_/oidc/audience"))
+        .respond_with(
+            ResponseTemplate::new(200)
+                .set_body_raw("{\"audience\":\"testpypi\"}", "application/json"),
+        )
+        .mount(&server)
+        .await;
+
+    // Mint token endpoint returns a short-lived API token
+    Mock::given(method("POST"))
+        .and(path("/_/oidc/mint-token"))
+        .respond_with(
+            ResponseTemplate::new(200).set_body_raw("{\"token\":\"apitoken\"}", "application/json"),
+        )
+        .mount(&server)
+        .await;
+
+    // Upload endpoint requires the minted token as Basic auth
+    Mock::given(method("POST"))
+        .and(path("/upload"))
+        .and(basic_auth("__token__", "apitoken"))
+        .respond_with(ResponseTemplate::new(200))
+        .mount(&server)
+        .await;
+
+    uv_snapshot!(context.filters(), context.publish()
+        .arg("--trusted-publishing")
+        .arg("always")
+        .arg("--publish-url")
+        .arg(format!("{}/upload", server.uri()))
+        .arg("../../scripts/links/ok-1.0.0-py3-none-any.whl")
+        // Emulate GitLab CI with TESTPYPI_ID_TOKEN present
+        .env(EnvVars::GITLAB_CI, "true")
+        .env_remove(EnvVars::GITHUB_ACTIONS)
+        .env("TESTPYPI_ID_TOKEN", "gitlab-oidc-jwt"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Publishing 1 file to http://[LOCALHOST]/upload
+    Uploading ok-1.0.0-py3-none-any.whl ([SIZE])
+    "
+    );
+}
